@@ -2,33 +2,11 @@ package DateTime::Format::Natural::Lang::DE;
 
 use strict;
 use warnings;
+use base qw(DateTime::Format::Natural::Lang::Base);
 
 our $VERSION = '0.4';
 
-our ($AUTOLOAD, %data_weekdays, %data_months);
-
-sub __new {
-    my $class = shift;
-
-    my $obj = {};
-    $obj->{weekdays} = \%data_weekdays;
-    $obj->{months}   = \%data_months;
-
-    return bless $obj, $class || ref($class);
-}
-
-AUTOLOAD {
-    my ($self, $exp) = @_;
-
-    my $sub = $AUTOLOAD;
-    $sub =~ s/^.*:://;
-
-    if (substr($sub, 0, 2) eq '__') {
-       $sub =~ s/^__//;
-       no strict 'refs';
-       return ${$sub}{$exp};
-    }
-}
+our (%data_weekdays, %data_months);
 
 {
     my $i = 1;
@@ -125,7 +103,7 @@ __END__
 
 =head1 NAME
 
-DateTime::Format::Natural::Lang::DE - German specific regular expressions and variables
+DateTime::Format::Natural::Lang::DE - German translation metadata
 
 =head1 DESCRIPTION
 
